<?php

	/**
	 * @author George Mathew K <george@gladsys.in>
	 * @since 1.8.0	 
	 * @package trafficanalyzer
	 * @license GPL V2 
	 */

	class TA_Line_Chart {
		private $resource;
		private $chart;
		private $x_labels=array();
		private $resource_labels=array();
		
		/**
		 * 
		 * Array of solid_dot objects
		 * @var array solid_dot objects
		 */
		private $dot;
		
		
		
		/**
		 * Constructor function 
		 * @since 1.8.0
		 * @param TA_Resource $resource
		 */
		public function __construct(TA_Resource $resource,TA_Period $period){
			$this->resource = $resource;
			$this->chart = new open_flash_chart();
			$this->set_x_y_axis($period);
			$this->set_lines($period);
			$this->set_title($period);
			
		}
		
		
		
		/**
		 * 
		 * Creates X and Y Axis and their labels
		 * @since 1.8.0
		 */
		public function set_x_y_axis(TA_Period $period){			
			$labels=array();
			$y_min=0;
			$y_max=0;
			$no_steps=10;
			
			$no_x_labels_limit = 10;	// Sets maximum number of X-Axis labels
			$no_x_labels = 0;
			$step_x=0;
			
			$res = $this->resource;
			$res_data = $res->get_resource();
			
			foreach($res_data as $row) {
				
				/*
				 * Generating All X-Axis labels
				 */
				$this->x_labels["'".$row['period']."'"] = $row['period'];
				
				/*
				 * Determining highest count value for setting y-axis range
				 */
				if($y_max<$row['count']){
					$y_max = $row['count'];
				}				
				
				/*
				 * Creating Dot values corresponding to X-Axis label and Resource Title
				 */
				if($row['title']!="") {										
					$this->resource_labels[$row['id']] = $row['title'];					
					$this->dot["'".$row['period']."'"]["'".$row['title']."'"] = new solid_dot((int)$row['count']);
					
					/* Grid Data */
					$grid_data["key"] = $row['id'];	// post_id
					$grid_data["article"] = $row['title'];		// post_title
					
					if($period->get_periodicity()=='d' ){
                    	$grid_data['sdate'] = date('Y/m/d',$row['period_ts']);
                        $grid_data['edate'] = date('Y/m/d',$row['period_ts']);
                        $grid_data['period_title'] = "Views on ". $row['period'];
                    }else if($period->get_periodicity()=='w') {
		                $grid_data['sdate'] = ta_week_start_date(intval(substr($row['period'],0,2)), intval(substr($row['period'],3,4)));                                         
                        $grid_data['edate'] = date('Y/m/d', strtotime('+6 days', strtotime($grid_data['sdate'])));
                        $grid_data['period_title'] = "Views on week ".$row['period']." (".date('d-M-Y',strtotime($grid_data['sdate']))." - ". date('d-M-Y',strtotime($grid_data['edate'])). ")";                                                                                                
                    }else if($period->get_periodicity() == 'm') {
                    	$grid_data['sdate'] = date('Y/m/d',strtotime("01"."-".$row['period'])) ;// Hyphen(1) is the separator                                           
                    	$grid_data['edate'] = date('Y/m/d',strtotime(date('t', strtotime($grid_data['sdate']))."-".$row['period'])) ;
						$grid_data['period_title'] = "Views on ".$row['period'];
                    }
											
					$data_json = json_encode($grid_data);
					$this->dot["'".$row['period']."'"]["'".$row['title']."'"]->on_click("show_dialog($data_json)");					
					/* Grid Data */
				}								
			}
			
			/*
			 * X-Axis Step
			 */
			$no_x_labels = count($this->x_labels);
			$step_x = intval($no_x_labels / $no_x_labels_limit ) ;		
			$i=1;
			
			/*
			 * X-Axis labels to be displayed
			 */
			foreach($this->x_labels as $lbl){
				if($step_x!=0){
					if($i%$step_x==0)
						$x_lbls[] = $lbl;
					else
						$x_lbls[] = "";				
					$i++;
				}else {
					$x_lbls[] = $lbl;
				}
				
			}
			
			/*
			 * Y-Axis Step
			 */
			$step = intval($y_max / $no_steps) ; 
			
			$x_axis_labels = new x_axis_labels();
			$x_axis_labels->set_labels($x_lbls);
			$x_axis_labels->rotate(320);
			
			$x_axis = new x_axis();
			$y_axis = new y_axis();
			
			$x_axis->set_labels($x_axis_labels);
			$y_axis->set_range($y_min, $y_max, $step);			

			$this->chart->set_x_axis($x_axis);
			$this->chart->set_y_axis($y_axis) ;
		}
		
		
		
		/**
		 * 
		 * Generating the Lines corresponding to all resources
		 * @since 1.8.0
		 */
		public function set_lines(TA_Period $period){			
			$data = array();
			/*
			 * Iterates through all the resources 
			 */
			foreach($this->resource_labels as $id=>$r_label){
				reset($this->x_labels);
				/*
				 * Iterates through all the X-Axis labels
				 */
				foreach($this->x_labels as $x) {

					
					$tip = "(#key#)<br>";															// Tooltip Line1
					if($period->is_weekly()){
						$tip .= "Week Start Date :" . date('d-M-Y',strtotime(ta_week_start_date(intval(substr($x,0,2)),intval(substr($x,3,4))))) . "<br>" ;
						$tip .= "Week End Date :" . date('d-M-Y',strtotime("+6 days",strtotime(ta_week_start_date(intval(substr($x,0,2)),intval(substr($x,3,4)))))) . "<br>" ; 
					}
					$tip .= "View on:  ".$x ."<br>" ;												// Tooltip Line2
					$tip .= "View Count: #val#/".$this->resource->get_total($x)."<br>";				// Tooltip Line3
					$tip .= "Percentage: ".ta_get_percentage($this->dot["'".$x."'"]["'".$r_label."'"]->value, $this->resource->get_total($x));  // Tooltip Line4
					
					/*
					 * Retrieving all the Dot objects created in set_x_y_axis()
					 */
					if(isset($this->dot["'".$x."'"]["'".$r_label."'"])){	
						$dot = 	$this->dot["'".$x."'"]["'".$r_label."'"];
						$dot->tooltip($tip);		
						$dot->size(3);			
						$data[] = $dot;
					}else{
						$dot = new solid_dot(0);
						$dot->size(3);
						$dot->tooltip($tip);
						$data[] = $dot;
					}				
				}
				$line = new line();				
				$line->set_colour(ta_get_color($id));
				$line->set_values($data);
				$line->set_text("$r_label");
				//$line->set_width(3);
				$data = array();
				$this->chart->add_element($line);
			}			
		}
		
	
		/**
		 * 
		 * Draws the chart
		 * @since 1.8.0
		 */
		public function draw(){
			echo $this->chart->toString();
		}	

		/**
		 * 
		 * Sets a title to this chart
		 * @since 1.8.0
		 */
		public function set_title(TA_Period $period){
			$title_text="";
			switch($period->get_periodicity()){
				case 'd':
					$title_text = "Views from ". date('d-M-Y',strtotime($period->get_start_date())) . " to " . date('d-M-Y',strtotime($period->get_end_date()));
					break;
				case 'w':
					$title_text = "Views from ". date('\W\e\e\k\-W\(Y\)',strtotime($period->get_start_date())) . " to " . date('\W\e\e\k\-W\(o\)',strtotime($period->get_end_date()));
					break;	
				case 'm':
					$title_text = "Views from ". date('M-Y',strtotime($period->get_start_date())) . " to " . date('M-Y',strtotime($period->get_end_date())) ;
					break;			
					
			}
			
			$title_style = "font-size:20px;padding:20px;width:400px";
			$title = new title($title_text);
			$title->set_style($title_style);
			$this->chart->set_title($title);			

			
		}
		
	}